@@ -7,32 +7,75 @@ import MySQLdb.cursors
 import MySQLdb.converters
 from MySQLdb import IntegrityError as DatabaseIntegrityError
 from MySQLdb import OperationalError as DatabaseOperationalError
-import logging
 import os
-import re
 import time
 import tempfile
+from sql import Flavor, Expression
+from sql.functions import Extract, Overlay, CharLength
 
-QUOTE_SEPARATION = re.compile(r"(.*?)('.*?')", re.DOTALL)
-EXTRACT_EPOCH_PATTERN = re.compile(r'EXTRACT\s*\(\s*EPOCH\s+FROM',
-        re.I)
-CAST_VARCHAR_PATTERN = re.compile(r' AS VARCHAR\)', re.I)
-CAST_INTEGER_PATTERN = re.compile(r' AS (INTEGER|BIGINT)\)', re.I)
-SPLIT_PART_LEFT_PATTERN = re.compile(r'SPLIT_PART\((.*?),', re.I)
-SPLIT_PART_RIGHT_PATTERN = re.compile(r'^,(\d)', re.I)
-def _replace_split_part_right(mobj):
-    pos = int(mobj.group(1))
-    if pos not in (1, 2):
-        raise Exception('SPLIT_PART is only partially implemented for MySQL')
-    if pos == 2:
-        return ', -1'
-    return ', 1'
+__all__ = ['Database', 'DatabaseIntegrityError', 'DatabaseOperationalError',
+    'Cursor']
+
+
+class MySQLExtract(Extract):
+
+    def is_epoch(self):
+        return self.args[0].upper() == 'EPOCH'
+
+    def __str__(self):
+        if self.is_epoch():
+            return 'UNIX_TIMESTAMP(%s)' % self._format(self.args[1])
+        return super(MySQLExtract, self).__str__()
+
+    @property
+    def params(self):
+        if self.is_epoch():
+            arg = self.args[1]
+            if isinstance(arg, Expression):
+                return arg.params
+            else:
+                return (arg,)
+        return super(MySQLExtract, self).params
+
+
+class MySQLOverlay(Overlay):
+
+    @property
+    def mysql_args(self):
+        if len(self.args) == 3:
+            string, placing, from_ = self.args
+            for_ = CharLength(placing)
+        else:
+            string, placing, from_, for_ = self.args
+        return (string, from_, placing, string, from_, for_)
+
+    def __str__(self):
+        return ('CONCAT(SUBSTRING(%s FROM 1 FOR %s), %s, '
+            'SUBSTRING(%s FROM %s + 1 + %s))'
+            % tuple(map(self._format, self.mysql_args)))
+
+    @property
+    def params(self):
+        p = ()
+        for arg in self.mysql_args:
+            if isinstance(arg, Expression):
+                p += arg.params
+            else:
+                p += (arg,)
+        return p
+
+
+MAPPING = {
+    Extract: MySQLExtract,
+    Overlay: MySQLOverlay,
+    }
 
 
 class Database(DatabaseInterface):
 
     _list_cache = None
     _list_cache_timestamp = None
+    flavor = Flavor(max_limit=18446744073709551610, function_mapping=MAPPING)
 
     def connect(self):
         return self
@@ -63,8 +106,8 @@ class Database(DatabaseInterface):
         return
 
     def create(self, cursor, database_name):
-        cursor.execute('CREATE DATABASE `' + database_name + '` ' \
-                'DEFAULT CHARACTER SET = \'utf8\'')
+        cursor.execute('CREATE DATABASE `' + database_name + '` '
+            'DEFAULT CHARACTER SET = \'utf8\'')
         Database._list_cache = None
 
     def drop(self, cursor, database_name):
@@ -169,39 +212,29 @@ class Database(DatabaseInterface):
 
     @staticmethod
     def init(cursor):
-        from trytond.tools import safe_eval
+        from trytond.modules import get_module_info
         sql_file = os.path.join(os.path.dirname(__file__), 'init.sql')
         with open(sql_file) as fp:
             for line in fp.read().split(';'):
-                if (len(line)>0) and (not line.isspace()):
+                if (len(line) > 0) and (not line.isspace()):
                     cursor.execute(line)
 
-        for i in ('ir', 'workflow', 'res', 'webdav'):
-            root_path = os.path.join(os.path.dirname(__file__), '..', '..')
-            tryton_file = os.path.join(root_path, i, '__tryton__.py')
-            mod_path = os.path.join(root_path, i)
-            with open(tryton_file) as fp:
-                info = safe_eval(fp.read())
-            active = info.get('active', False)
-            if active:
+        for module in ('ir', 'res', 'webdav'):
+            state = 'uninstalled'
+            if module in ('ir', 'res'):
                 state = 'to install'
-            else:
-                state = 'uninstalled'
-            cursor.execute('INSERT INTO ir_module_module ' \
-                    '(create_uid, create_date, author, website, name, ' \
-                    'shortdesc, description, state) ' \
-                    'VALUES (%s, now(), %s, %s, %s, %s, %s, %s)',
-                    (0, info.get('author', ''),
-                info.get('website', ''), i, info.get('name', False),
-                info.get('description', ''), state))
+            info = get_module_info(module)
+            cursor.execute('INSERT INTO ir_module_module '
+                '(create_uid, create_date, name, state) '
+                'VALUES (%s, now(), %s, %s)',
+                (0, module, state))
             cursor.execute('SELECT LAST_INSERT_ID()')
-            module_id = cursor.fetchone()[0]
-            dependencies = info.get('depends', [])
-            for dependency in dependencies:
-                cursor.execute('INSERT INTO ir_module_module_dependency ' \
-                        '(create_uid, create_date, module, name) ' \
-                        'VALUES (%s, now(), %s, %s)',
-                        (0, module_id, dependency))
+            module_id, = cursor.fetchone()
+            for dependency in info.get('depends', []):
+                cursor.execute('INSERT INTO ir_module_module_dependency '
+                    '(create_uid, create_date, module, name) '
+                    'VALUES (%s, now(), %s, %s)',
+                    (0, module_id, dependency))
 
 
 class _Cursor(MySQLdb.cursors.Cursor):
@@ -235,45 +268,17 @@ class Cursor(CursorInterface):
         super(Cursor, self).__init__()
         self._conn = conn
         self.database_name = database_name
-        self.dbname = self.database_name #XXX to remove
+        self.dbname = self.database_name  # XXX to remove
         self.cursor = conn.cursor(_Cursor)
 
     def __getattr__(self, name):
         return getattr(self.cursor, name)
 
     def execute(self, sql, params=None):
-        buf = ""
-        split_part_found = False
-        for nquote, quote in QUOTE_SEPARATION.findall(sql+"''"):
-            nquote = nquote.replace('ilike', 'like')
-            nquote = re.sub(EXTRACT_EPOCH_PATTERN, r'UNIX_TIMESTAMP(',
-                    nquote)
-            nquote = re.sub(CAST_VARCHAR_PATTERN, r' AS CHAR)',
-                    nquote)
-            nquote = re.sub(CAST_INTEGER_PATTERN, r' AS SIGNED INTEGER)',
-                    nquote)
-            if split_part_found:
-                nquote = re.sub(SPLIT_PART_RIGHT_PATTERN, 
-                        _replace_split_part_right, nquote)
-                split_part_found = False
-            nquote, split_part_found = re.subn(SPLIT_PART_LEFT_PATTERN,
-                    r'SUBSTRING_INDEX(\1, ', nquote)
-
-            buf += nquote + quote
-        sql = buf[:-2]
-        try:
-            if params:
-                res = self.cursor.execute(sql, params)
-            else:
-                res = self.cursor.execute(sql)
-        except Exception, exception:
-            logger = logging.getLogger('sql')
-            logger.error('Wrong SQL: ' + sql + ' ' + str(params))
-            if isinstance(exception, MySQLdb.Error):
-                exception.args = exception.args[1:]
-                raise exception
-            raise
-        return res
+        if params:
+            return self.cursor.execute(sql, params)
+        else:
+            return self.cursor.execute(sql)
 
     def close(self, close=False):
         self.cursor.close()
@@ -297,12 +302,6 @@ class Cursor(CursorInterface):
                     'ir_ui_menu',
                     'res_user',
                     'res_group',
-                    'wkf',
-                    'wkf_activity',
-                    'wkf_transition',
-                    'wkf_instance',
-                    'wkf_workitem',
-                    'wkf_witm_trans',
                     'ir_module_module',
                     'ir_module_module_dependency',
                     'ir_translation',
@@ -326,7 +325,7 @@ class Cursor(CursorInterface):
 
     def limit_clause(self, select, limit=None, offset=None):
         if offset and limit is None:
-            limit = 18446744073709551610 #max bigint
+            limit = 18446744073709551610  # max bigint
         if limit is not None:
             select += ' LIMIT %d' % limit
         if offset is not None and offset != 0:
