@@ -39,9 +39,9 @@ class ModelStorage(Model):
     """
 
     create_uid = fields.Many2One('res.user', 'Create User', readonly=True)
-    create_date = fields.DateTime('Create Date', readonly=True)
+    create_date = fields.Timestamp('Create Date', readonly=True)
     write_uid = fields.Many2One('res.user', 'Write User', readonly=True)
-    write_date = fields.DateTime('Write Date', readonly=True)
+    write_date = fields.Timestamp('Write Date', readonly=True)
     rec_name = fields.Function(fields.Char('Name'), 'get_rec_name',
             searcher='search_rec_name')
 
@@ -538,7 +538,7 @@ class ModelStorage(Model):
             def warn(msgname, *args):
                 msg = cls.raise_user_error(msgname, args,
                         raise_exception=False)
-                warnings.warn(msg)
+                logger.warn(msg)
 
             def get_selection(selection, value):
                 res = None
@@ -684,11 +684,13 @@ class ModelStorage(Model):
                     elif field_type == 'numeric':
                         res = Decimal(value) if value else None
                     elif field_type == 'date':
-                        res = value and datetime.date(*time.strptime(value,
-                            '%Y-%m-%d')[:3])
+                        res = (datetime.date(
+                                *time.strptime(value, '%Y-%m-%d')[:3])
+                            if value else None)
                     elif field_type == 'datetime':
-                        res = value and datetime.datetime(*time.strptime(value,
-                            '%Y-%m-%d %H:%M:%S')[:6])
+                        res = (datetime.datetime(
+                                *time.strptime(value, '%Y-%m-%d %H:%M:%S')[:6])
+                            if value else None)
                     elif field_type == 'selection':
                         res = get_selection(this_field_def['selection'], value)
                     elif field_type == 'many2one':
@@ -741,9 +743,9 @@ class ModelStorage(Model):
         ModelData = pool.get('ir.model.data')
 
         # logger for collecting warnings for the client
-        warnings = logging.Logger("import")
+        logger = logging.Logger("import")
         warning_stream = StringIO.StringIO()
-        warnings.addHandler(logging.StreamHandler(warning_stream))
+        logger.addHandler(logging.StreamHandler(warning_stream))
 
         len_fields_names = len(fields_names)
         assert all(len(x) == len_fields_names for x in data)
@@ -822,7 +824,7 @@ class ModelStorage(Model):
         '''
         parent_type = cls._fields[parent]._type
 
-        if parent_type not in ('many2one', 'many2many'):
+        if parent_type not in ('many2one', 'many2many', 'one2one'):
             raise Exception(
                 'Unsupported field type "%s" for field "%s" on "%s"'
                 % (parent_type, parent, cls.__name__))
@@ -891,7 +893,8 @@ class ModelStorage(Model):
             else:
                 return all(method(r) for r in records)
         for field in cls._constraints:
-            warnings.warn('_constraints is deprecated, override validate instead',
+            warnings.warn(
+                '_constraints is deprecated, override validate instead',
                 DeprecationWarning, stacklevel=2)
             if not call(field[0]):
                 cls.raise_user_error(field[1])
@@ -923,6 +926,7 @@ class ModelStorage(Model):
                             return True
             return False
 
+        ctx_pref['active_test'] = False
         with Transaction().set_context(ctx_pref):
             for field_name, field in cls._fields.iteritems():
                 if isinstance(field, fields.Function) and \
@@ -1132,7 +1136,6 @@ class ModelStorage(Model):
 
         cls.validate(records)
 
-
     @classmethod
     def _clean_defaults(cls, defaults):
         pool = Pool()
@@ -1409,6 +1412,8 @@ class EvalEnvironment(dict):
         if item in self._model._fields:
             value = getattr(self._record, item)
             if isinstance(value, Model):
+                if self._model._fields[item]._type == 'reference':
+                    return str(value)
                 return value.id
             elif isinstance(value, (list, tuple)):
                 return [r.id for r in value]
