@@ -229,7 +229,7 @@ class ModelView(Model):
                 xml = ''
             result['type'] = view_type
             result['arch'] = xml
-            result['field_childs'] = False
+            result['field_childs'] = None
             result['view_id'] = 0
 
         # Update arch and compute fields from arch
@@ -301,11 +301,13 @@ class ModelView(Model):
                         raise_exception=False):
                     return False
             if field._type in ('many2many', 'one2one'):
-                if not ModelAccess.check(field.target, mode='read',
-                        raise_exception=False):
+                if (field.target
+                        and not ModelAccess.check(field.target, mode='read',
+                            raise_exception=False)):
                     return False
-                elif not ModelAccess.check(field.relation_name,
-                        mode='read', raise_exception=False):
+                elif (field.relation_name
+                        and not ModelAccess.check(field.relation_name,
+                            mode='read', raise_exception=False)):
                     return False
             if field._type == 'reference':
                 selection = field.selection
@@ -482,6 +484,11 @@ class ModelView(Model):
         if element.tag == 'tree' and element.get('sequence'):
             fields_attrs.setdefault(element.get('sequence'), {})
 
+        if element.tag == 'calendar':
+            for attr in ('dtstart', 'dtend'):
+                if element.get(attr):
+                    fields_attrs.setdefault(element.get(attr), {})
+
         if childs:
             for field in element:
                 fields_attrs = cls.__view_look_dom(field, type,
