@@ -10,7 +10,9 @@ import imp
 import operator
 import ConfigParser
 from glob import iglob
-import datetime
+
+from sql import Table
+from sql.functions import Now
 
 import trytond.tools as tools
 from trytond.config import CONFIG
@@ -18,6 +20,9 @@ from trytond.transaction import Transaction
 from trytond.cache import Cache
 import trytond.convert as convert
 
+ir_module = Table('ir_module_module')
+ir_model_data = Table('ir_model_data')
+
 OPJ = os.path.join
 MODULES_PATH = os.path.abspath(os.path.dirname(__file__))
 
@@ -178,17 +183,20 @@ def create_graph(module_list):
             packages.append((package, deps, xdep, info))
         packages.pop(0)
 
-    for package, deps, xdep, info in packages:
+    missings = set()
+    for package, deps, _, _ in packages:
         if package not in later:
             continue
-        missings = [x for x in deps if x not in graph]
-        raise Exception('%s unmet dependencies: %s' % (package, missings))
+        missings |= set((x for x in deps if x not in graph))
+    if missings:
+        raise Exception('Missing dependencies: %s' % list(missings
+                - set((p[0] for p in packages))))
     return graph, packages, later
 
 
 def is_module_to_install(module):
     for kind in ('init', 'update'):
-        if 'all' in CONFIG[kind] and module != 'test':
+        if 'all' in CONFIG[kind] and module != 'tests':
             return True
         elif module in CONFIG[kind]:
             return True
@@ -204,9 +212,8 @@ def load_module_graph(graph, pool, lang=None):
     cursor = Transaction().cursor
 
     modules = [x.name for x in graph]
-    cursor.execute('SELECT name, state FROM ir_module_module '
-        'WHERE name in (' + ','.join(('%s',) * len(modules)) + ')',
-        modules)
+    cursor.execute(*ir_module.select(ir_module.name, ir_module.state,
+            where=ir_module.name.in_(modules)))
     module2state = dict(cursor.fetchall())
 
     for package in graph:
@@ -214,7 +221,6 @@ def load_module_graph(graph, pool, lang=None):
         if module not in MODULES:
             continue
         logger.info(module)
-        sys.stdout.flush()
         classes = pool.setup(module)
         package_state = module2state.get(module, 'uninstalled')
         if (is_module_to_install(module)
@@ -232,7 +238,8 @@ def load_module_graph(graph, pool, lang=None):
                     models_to_update_history.add(model.__name__)
 
             #Instanciate a new parser for the package:
-            tryton_parser = convert.TrytondXmlHandler(pool=pool, module=module)
+            tryton_parser = convert.TrytondXmlHandler(pool=pool, module=module,
+                module_state=package_state)
 
             for filename in package.info.get('xml', []):
                 filename = filename.replace('/', os.sep)
@@ -254,17 +261,17 @@ def load_module_graph(graph, pool, lang=None):
                 Translation = pool.get('ir.translation')
                 Translation.translation_import(lang2, module, filename)
 
-            cursor.execute('SELECT id FROM ir_module_module '
-                'WHERE name = %s', (package.name,))
+            cursor.execute(*ir_module.select(ir_module.id,
+                    where=(ir_module.name == package.name)))
             try:
                 module_id, = cursor.fetchone()
-                cursor.execute('UPDATE ir_module_module SET state = %s '
-                    'WHERE id = %s', ('installed', module_id))
+                cursor.execute(*ir_module.update([ir_module.state],
+                        ['installed'], where=(ir_module.id == module_id)))
             except TypeError:
-                cursor.execute('INSERT INTO ir_module_module '
-                    '(create_uid, create_date, name, state) '
-                    'VALUES (%s, %s, %s, %s)', (0, datetime.datetime.now(),
-                        package.name, 'installed'))
+                cursor.execute(*ir_module.insert(
+                        [ir_module.create_uid, ir_module.create_date,
+                            ir_module.name, ir_module.state],
+                        [[0, Now(), package.name, 'installed']]))
             module2state[package.name] = 'installed'
 
         cursor.commit()
@@ -296,7 +303,7 @@ def get_module_list():
     module_list.add('ir')
     module_list.add('res')
     module_list.add('webdav')
-    module_list.add('test')
+    module_list.add('tests')
     return list(module_list)
 
 
@@ -310,15 +317,15 @@ def register_classes():
     trytond.res.register()
     import trytond.webdav
     trytond.webdav.register()
-    import trytond.test
-    trytond.test.register()
+    import trytond.tests
+    trytond.tests.register()
     logger = logging.getLogger('modules')
 
     for package in create_graph(get_module_list())[0]:
         module = package.name
         logger.info('%s:registering classes' % module)
 
-        if module in ('ir', 'res', 'webdav', 'test'):
+        if module in ('ir', 'res', 'webdav', 'tests'):
             MODULES.append(module)
             continue
 
@@ -365,18 +372,19 @@ def load_modules(database_name, pool, update=False, lang=None):
         cursor = Transaction().cursor
         if update:
             # Migration from 2.2: workflow module removed
-            cursor.execute('DELETE FROM ir_module_module '
-                'WHERE name = %s', ('workflow',))
+            cursor.execute(*ir_module.delete(
+                    where=(ir_module.name == 'workflow')))
             if 'all' in CONFIG['init']:
-                cursor.execute("SELECT name FROM ir_module_module "
-                    "WHERE name != \'test\'")
+                cursor.execute(*ir_module.select(ir_module.name,
+                        where=(ir_module.name != 'tests')))
             else:
-                cursor.execute("SELECT name FROM ir_module_module "
-                    "WHERE state IN ('installed', 'to install', "
-                    "'to upgrade', 'to remove')")
+                cursor.execute(*ir_module.select(ir_module.name,
+                        where=ir_module.state.in_(('installed', 'to install',
+                                'to upgrade', 'to remove'))))
         else:
-            cursor.execute("SELECT name FROM ir_module_module "
-                "WHERE state IN ('installed', 'to upgrade', 'to remove')")
+            cursor.execute(*ir_module.select(ir_module.name,
+                    where=ir_module.state.in_(('installed', 'to upgrade',
+                            'to remove'))))
         module_list = [name for (name,) in cursor.fetchall()]
         if update:
             for module in CONFIG['init'].keys():
@@ -394,21 +402,23 @@ def load_modules(database_name, pool, update=False, lang=None):
             raise
 
         if update:
-            cursor.execute("SELECT name FROM ir_module_module "
-                "WHERE state IN ('to remove')")
+            cursor.execute(*ir_module.select(ir_module.name,
+                    where=(ir_module.state == 'to remove')))
             fetchall = cursor.fetchall()
             if fetchall:
                 for (mod_name,) in fetchall:
                     #TODO check if ressource not updated by the user
-                    cursor.execute('SELECT model, db_id FROM ir_model_data '
-                        'WHERE module = %s '
-                        'ORDER BY id DESC', (mod_name,))
+                    cursor.execute(*ir_model_data.select(ir_model_data.model,
+                            ir_model_data.db_id,
+                            where=(ir_model_data.module == mod_name),
+                            order_by=ir_model_data.id.desc))
                     for rmod, rid in cursor.fetchall():
                         Model = pool.get(rmod)
                         Model.delete([Model(rid)])
                     cursor.commit()
-                cursor.execute("UPDATE ir_module_module SET state = %s "
-                    "WHERE state IN ('to remove')", ('uninstalled',))
+                cursor.execute(*ir_module.update([ir_module.state],
+                        ['uninstalled'],
+                        where=(ir_module.state == 'to remove')))
                 cursor.commit()
                 res = False
 
