@@ -3,7 +3,6 @@
 from ..pool import Pool
 from .group import *
 from .user import *
-from .request import *
 from .ir import *
 
 
@@ -17,10 +16,6 @@ def register():
         UserGroup,
         Warning_,
         UserConfigStart,
-        Request,
-        RequestLink,
-        RequestHistory,
-        RequestReference,
         UIMenuGroup,
         ActionGroup,
         ModelFieldGroup,
